@@ -22,9 +22,11 @@ sub auto {
     my $server = try {
         $class->load($backend, @args);
     } catch {
-        warn "Autoloading '$backend' backend failed. Falling back to the Standalone. ",
-            "(You might need to install Plack::Handler::$backend from CPAN.  Caught error was: $_)\n"
-                if $ENV{PLACK_ENV} && $ENV{PLACK_ENV} eq 'development';
+        if (($ENV{PLACK_ENV}||'') eq 'development' or !/Can't locate/) {
+            warn "Autoloading '$backend' backend failed. Falling back to the Standalone. ",
+                "(You might need to install Plack::Handler::$backend from CPAN.  Caught error was: $_)\n"
+                    if $ENV{PLACK_ENV} && $ENV{PLACK_ENV} eq 'development';
+        }
         $class->load('Standalone' => @args);
     };
 
